(function() {
  var child_process, fs, path;

  child_process = require('child_process');

  fs = require('fs');

  path = require('path');

  module.exports = {
    getHomeDirectory: function() {
      if (process.platform === 'win32') {
        return process.env.USERPROFILE;
      } else {
        return process.env.HOME;
      }
    },
    getAtomDirectory: function() {
      var _ref;
      return (_ref = process.env.ATOM_HOME) != null ? _ref : path.join(this.getHomeDirectory(), '.atom');
    },
    getPackageCacheDirectory: function() {
      return path.join(this.getAtomDirectory(), '.node-gyp', '.atom', '.apm');
    },
    getResourcePath: function(callback) {
      if (process.env.ATOM_RESOURCE_PATH) {
        return process.nextTick(function() {
          return callback(process.env.ATOM_RESOURCE_PATH);
        });
      } else {
        if (process.platform === 'darwin') {
          return child_process.exec('mdfind "kMDItemCFBundleIdentifier == \'com.github.atom\'"', function(error, stdout, stderr) {
            var appLocation, _ref;
            if (stdout == null) {
              stdout = '';
            }
            appLocation = (_ref = stdout.split('\n')[0]) != null ? _ref : '/Applications/Atom.app';
            return callback("" + appLocation + "/Contents/Resources/app");
          });
        } else {
          return process.nextTick(function() {
            return callback('/usr/local/share/atom/resources/app');
          });
        }
      }
    },
    getReposDirectory: function() {
      var _ref;
      return (_ref = process.env.ATOM_REPOS_HOME) != null ? _ref : path.join(this.getHomeDirectory(), 'github');
    },
    getNodeUrl: function() {
      var _ref;
      return (_ref = process.env.ATOM_NODE_URL) != null ? _ref : 'https://gh-contractor-zcbenz.s3.amazonaws.com/atom-shell/dist';
    },
    getAtomPackagesUrl: function() {
      var _ref;
      return (_ref = process.env.ATOM_PACKAGES_URL) != null ? _ref : 'https://atom.io/api/packages';
    },
    getNodeVersion: function() {
      var _ref;
      return (_ref = process.env.ATOM_NODE_VERSION) != null ? _ref : '0.11.10';
    },
    getNodeArch: function() {
      switch (process.platform) {
        case 'darwin':
          return 'x64';
        case 'win32':
          return 'ia32';
        default:
          return process.arch;
      }
    },
    getUserConfigPath: function() {
      return path.resolve(__dirname, '..', '.apmrc');
    },
    isWin32: function() {
      return !!process.platform.match(/^win/);
    },
    isWindows64Bit: function() {
      return fs.existsSync("C:\\Windows\\SysWow64\\Notepad.exe");
    },
    x86ProgramFilesDirectory: function() {
      return process.env["ProgramFiles(x86)"] || process.env["ProgramFiles"];
    },
    isVs2010Installed: function() {
      var vsPath;
      if (!this.isWin32()) {
        return false;
      }
      vsPath = path.join(this.x86ProgramFilesDirectory(), "Microsoft Visual Studio 10.0", "Common7", "IDE");
      return fs.existsSync(vsPath);
    },
    isVs2012Installed: function() {
      var vsPath;
      if (!this.isWin32()) {
        return false;
      }
      vsPath = path.join(this.x86ProgramFilesDirectory(), "Microsoft Visual Studio 11.0", "Common7", "IDE");
      return fs.existsSync(vsPath);
    }
  };

}).call(this);
